==> haskell-io-streams-haproxy-1.0.1.0-197-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 io-streams-haproxy
version:              1.0.1.0
visibility:           public
id:                   io-streams-haproxy-1.0.1.0-8MVw0Lh5HFy9jTh7vBRwO5
key:                  io-streams-haproxy-1.0.1.0-8MVw0Lh5HFy9jTh7vBRwO5
license:              BSD-3-Clause
copyright:            (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer:           greg@gregorycollins.net
author:               Gregory Collins
homepage:             http://snapframework.com/
synopsis:             HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.

category:             Network, IO-Streams
abi:                  6e3eb1b257c8c6fa8fa9ac93f4a92a4e
exposed:              True
exposed-modules:      System.IO.Streams.Network.HAProxy
hidden-modules:       System.IO.Streams.Network.Internal.Address
import-dirs:          /usr/lib/ghc-9.0.2/site-local/io-streams-haproxy-1.0.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/io-streams-haproxy-1.0.1.0

hs-libraries:         HSio-streams-haproxy-1.0.1.0-8MVw0Lh5HFy9jTh7vBRwO5
depends:
    attoparsec-0.14.4-GTUovz5zqDi6zhtjAcFzCG base-4.15.1.0
    bytestring-0.10.12.1 io-streams-1.5.2.1-Dnap8gsB2Az7QqdgGhvfR0
    network-3.1.2.7-IxSapBmcUjdKlUh8acAzLk transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock

haddock-html:         /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-haproxy-1.0.1.0-199-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 io-streams-haproxy
version:              1.0.1.0
visibility:           public
id:                   io-streams-haproxy-1.0.1.0-Gt8g6VO91TL6WJK8FUJuBY
key:                  io-streams-haproxy-1.0.1.0-Gt8g6VO91TL6WJK8FUJuBY
license:              BSD-3-Clause
copyright:            (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer:           greg@gregorycollins.net
author:               Gregory Collins
homepage:             http://snapframework.com/
synopsis:             HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.

category:             Network, IO-Streams
abi:                  f4deb506abd266e6be4fe6dfcaece2dd
exposed:              True
exposed-modules:      System.IO.Streams.Network.HAProxy
hidden-modules:       System.IO.Streams.Network.Internal.Address
import-dirs:          /usr/lib/ghc-9.0.2/site-local/io-streams-haproxy-1.0.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/io-streams-haproxy-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/io-streams-haproxy-1.0.1.0

hs-libraries:         HSio-streams-haproxy-1.0.1.0-Gt8g6VO91TL6WJK8FUJuBY
depends:
    attoparsec-0.14.4-6yxyXEyzS3R3Ezwp1OCEqd base-4.15.1.0
    bytestring-0.10.12.1 io-streams-1.5.2.1-3uZSFrCYcDPJtfJIoEC5xb
    network-3.1.2.7-1L09W9zvGhC6IaYg8BuIRn transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock

haddock-html:         /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
